@@ -19,13 +19,16 @@
 # this snippet comes from
 # http://www.mechanicalcat.net/richard/log/Python/Simple_usage_of_Python_s_logging_module
 
-from os import path
+import os
 import logging
 
 logger = logging.getLogger('nl')
-here = path.join(path.dirname(__file__))
-log_file = here + '/clips/log.clp'
-if not path.isfile(log_file):
+here = os.path.join(os.path.dirname(__file__))
+log_dir = here + '/clips/'
+log_file = log_dir + 'log.clp'
+if not os.path.isfile(log_file):
+    if not os.path.isdir(log_dir):
+        os.mkdir(log_dir)
     f = open(log_file, 'w')
     f.write('log file for nl\n\n')
     f.close()
